Crate moosicbox_async_service

Crate moosicbox_async_service 

Re-exports

pub use log;
pub use moosicbox_task;
pub use tokio;

Macros

async_service
async_service_body
async_service_sequential

Structs

Arc
A thread-safe reference-counting pointer. ‘Arc’ stands for ‘Atomically Reference Counted’.
CancellationToken
A token which can be used to signal a cancellation request to one or more tasks.
Duration
A Duration type to represent a span of time, typically used for system timeouts.
HashMap
A hash map implemented with quadratic probing and SIMD lookup.
JoinError
Task failed to execute to completion.
JoinHandle
An owned permission to join on a task (await its termination).
Pin
A pointer which pins its pointee in place.
Receiver
The receiving end of a channel.
SendError
An error that may be emitted when attempting to send a value into a channel on a sender when all receivers are dropped.
Sender
A transmitting end of a channel.

Enums

RecvError
An error that may be emitted when attempting to wait for a value on a receiver when all senders are dropped and there are no more messages in the channel.

Traits

Future
A future represents an asynchronous computation, commonly obtained by use of async.

Functions

unbounded
Create a channel with no maximum capacity.

Attribute Macros

async_trait

Derive Macros

Error